km3modules\.common\.Wrap
========================

.. currentmodule:: km3modules.common

.. autoclass:: Wrap

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Wrap.__init__
      ~Wrap.add
      ~Wrap.configure
      ~Wrap.expose
      ~Wrap.finish
      ~Wrap.get
      ~Wrap.pre_finish
      ~Wrap.process
      ~Wrap.require
   
   

   
   
   